@@ -2,26 +2,30 @@ package Net::Whois::Object::AsBlock;
 
 use base qw/Net::Whois::Object/;
 
-# http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-7
-# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/as-block
-#
-# as-block:      [mandatory]  [single]     [primary/look-up key]
-# descr:         [optional]   [multiple]   [ ]
-# remarks:       [optional]   [multiple]   [ ]
-# org:           [optional]   [multiple]   [inverse key]
-# admin-c:       [mandatory]  [multiple]   [inverse key]
-# tech-c:        [mandatory]  [multiple]   [inverse key]
-# notify:        [optional]   [multiple]   [inverse key]
-# mnt-lower:     [optional]   [multiple]   [inverse key]
-# mnt-by:        [mandatory]  [multiple]   [inverse key]
-# changed:       [mandatory]  [multiple]   [ ]
-# source:        [mandatory]  [single]     [ ]
+# whois -t as-block
+# % This is the RIPE Database query service.
+# % The objects are in RPSL format.
+# %
+# % The RIPE Database is subject to Terms and Conditions.
+# % See http://www.ripe.net/db/support/db-terms-conditions.pdf
+# 
+# as-block:       [mandatory]  [single]     [primary/lookup key]
+# descr:          [optional]   [multiple]   [ ]
+# remarks:        [optional]   [multiple]   [ ]
+# org:            [optional]   [multiple]   [inverse key]
+# notify:         [optional]   [multiple]   [inverse key]
+# mnt-by:         [mandatory]  [single]     [inverse key]
+# mnt-lower:      [optional]   [multiple]   [inverse key]
+# changed:        [mandatory]  [multiple]   [ ]
+# source:         [mandatory]  [single]     [ ]
 
-__PACKAGE__->attributes( 'primary', ['as_block'] );
-__PACKAGE__->attributes( 'mandatory', [ 'as_block', 'admin_c', 'tech_c', 'mnt_by', 'changed', 'source' ] );
-__PACKAGE__->attributes( 'optional', [ 'descr', 'remarks', 'org', 'notify', 'mnt_lower' ] );
-__PACKAGE__->attributes( 'single', [ 'as_block', 'source', 'org' ] );
-__PACKAGE__->attributes( 'multiple', [ 'descr', 'remarks', 'admin_c', 'tech_c', 'notify', 'mnt_lower', 'mnt_by', 'changed' ] );
+# % This query was served by the RIPE Database Query Service version 1.74.1 (DB-4)
+
+__PACKAGE__->attributes( 'primary',     [ 'as_block' ] );
+__PACKAGE__->attributes( 'mandatory',   [ 'as_block', 'mnt_by', 'changed', 'source' ] );
+__PACKAGE__->attributes( 'optional',    [ 'descr', 'remarks', 'org', 'notify', 'mnt_lower' ] );
+__PACKAGE__->attributes( 'single',      [ 'as_block', 'mnt_by', 'source' ] );
+__PACKAGE__->attributes( 'multiple',    [ 'descr', 'remarks', 'org', 'notify', 'mnt_lower', 'changed' ] );
 
 # Found in the wild
 # org:
