@@ -3,26 +3,36 @@ package Net::Whois::Object::FilterSet;
 use base qw/Net::Whois::Object/;
 
 # http://www.ripe.net/data-tools/support/documentation/update-ref-manual#section-11
-# http://www.apnic.net/apnic-info/whois_search/using-whois/guide/filter-set
-#
-# filter-set:    [mandatory]  [single]     [primary/look-up key]
-# descr:         [mandatory]  [multiple]   [ ]
-# filter:        [mandatory]  [single]     [ ]
-# mp-filter:     [mandatory]  [single]     [ ]
-# remarks:       [optional]   [multiple]   [ ]
-# org:           [optional]   [multiple]   [inverse key]
-# tech-c:        [mandatory]  [multiple]   [inverse key]
-# admin-c:       [mandatory]  [multiple]   [inverse key]
-# notify:        [optional]   [multiple]   [inverse key]
-# mnt-by:        [mandatory]  [multiple]   [inverse key]
-# mnt-lower:     [optional]   [multiple]   [inverse key]
-# changed:       [mandatory]  [multiple]   [ ]
-# source:        [mandatory]  [single]     [ ]
-__PACKAGE__->attributes( 'primary',   ['filter_set'] );
-__PACKAGE__->attributes( 'mandatory', [ 'filter_set', 'filter', 'mp_filter', 'source' ] );
-__PACKAGE__->attributes( 'optional', [ 'remarks', 'org', 'notify', 'mnt_lower' ] );
-__PACKAGE__->attributes( 'single',    [ 'filter_set', 'filter', 'mp_filter', 'source' ] );
-__PACKAGE__->attributes( 'multiple',  [ 'descr', 'remarks', 'org', 'tech_c', 'admin_c', 'notify', 'mnt_by', 'mnt_lower', 'changed' ] );
+
+# whois -t filter-set
+# % This is the RIPE Database query service.
+# % The objects are in RPSL format.
+# %
+# % The RIPE Database is subject to Terms and Conditions.
+# % See http://www.ripe.net/db/support/db-terms-conditions.pdf
+# 
+# filter-set:     [mandatory]  [single]     [primary/lookup key]
+# descr:          [mandatory]  [multiple]   [ ]
+# filter:         [optional]   [single]     [ ]
+# mp-filter:      [optional]   [single]     [ ]
+# remarks:        [optional]   [multiple]   [ ]
+# org:            [optional]   [multiple]   [inverse key]
+# tech-c:         [mandatory]  [multiple]   [inverse key]
+# admin-c:        [mandatory]  [multiple]   [inverse key]
+# notify:         [optional]   [multiple]   [inverse key]
+# mnt-by:         [mandatory]  [multiple]   [inverse key]
+# mnt-lower:      [optional]   [multiple]   [inverse key]
+# changed:        [mandatory]  [multiple]   [ ]
+# source:         [mandatory]  [single]     [ ]
+# 
+# % This query was served by the RIPE Database Query Service version 1.74.1 (DB-4)
+
+
+__PACKAGE__->attributes( 'primary',     [ 'filter_set' ] );
+__PACKAGE__->attributes( 'mandatory',   [ 'filter_set', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
+__PACKAGE__->attributes( 'optional',    [ 'filter', 'mp_filter', 'remarks', 'org', 'notify', 'mnt_lower' ] );
+__PACKAGE__->attributes( 'single',      [ 'filter_set', 'filter', 'mp_filter', 'source' ] );
+__PACKAGE__->attributes( 'multiple',    [ 'descr', 'remarks', 'org', 'tech_c', 'admin_c', 'notify', 'mnt_by', 'mnt_lower', 'changed' ] );
 
 =head1 NAME
 
